@@ -1,16 +1,20 @@
-from attest import AssertImportHook
+from attest import AssertImportHook, COMPILES_AST
 from contextlib import contextmanager
 import django
 from django.test.simple import DjangoTestSuiteRunner
+import logging
 from pkg_resources import parse_version
-import warnings
 
 
-def _fix_for_django():
-    if parse_version(django.get_version()) < parse_version('1.4'):
-        warnings.warn("Django <1.4 has broken import infrastructure, Attest's"
-                      " assert hook will be disabled.")
-        AssertImportHook.disable()
+logger = logging.getLogger("django_attest")
+
+
+if parse_version(django.get_version()) < parse_version('1.4'):
+    logger.info("Django <1.4 has broken import infrastructure, Attest's"
+                " assert hook will be disabled.")
+    AssertImportHook.disable()
+elif COMPILES_AST:
+    AssertImportHook.enable()
 
 
 @contextmanager
@@ -18,9 +22,6 @@ def testing_environment():
     """
     Context manager to put Django into a state suitable for testing.
     """
-    # patch django bugs
-    _fix_for_django()
-
     # setup test environment
     runner = DjangoTestSuiteRunner()
     runner.setup_test_environment()
